@@ -33,8 +33,18 @@ Returns a magma-list containing the file name. Takes the names as input.
     goi.gis
     
 """
-# Get the sha1_berechnen module. 
-from sha1_berechnen import sha1_berechnen
+
+__depends__ = 'yaml, os'
+
+#: The name of the file list parameter
+FILE_LIST_NAME = "files"
+#: The name of the dict holding the hashes and other unique identifiers. 
+URN_PARAMETER_NAME = "urn"
+#: The header (magic line) of Magma v0.4 files. 
+MAGMA_0_4_HEADER = "#MAGMAv0.4"
+
+# Get the sha1_gnutella module to create a sha1 for Gnutella. 
+from sha1_gnutella import sha1_gnutella
 # And get the yaml dumper and loader
 from yaml import dump, load
 # And the dirname to be able to strip it. 
@@ -50,25 +60,35 @@ def strip_dirname(path):
     return filename
 
 class Magma: 
-    def __init__(self, inputfilenames): 
+    def __init__(self, inputfilenames):
+        #: The names of the files. 
         self.filenames = inputfilenames
+        #: Sha1 values to the files. The sha1 gets computed for each one here, so this isn't ambigous. 
         self.sha1 = {}
+        # Add sha1 hashs for each file. 
         for i in self.filenames: 
-            self.sha1[i] = sha1_berechnen(i)
+            self.sha1[i] = sha1_gnutella(i)
+        #: The raw python data of the Magma file. 
+        self.data = self.data()
+        #: The yaml representation. 
         self.magma = self.magma()
-        self.data = load(self.magma)
         
-    def magma(self): 
+    def data(self):
+        """Calculate the Python data of the Magma file."""
         magma = {}
         list_of_magnets = []
         for i in self.filenames: 
             magnet = {}
-            magnet['hash'] = {}
-            magnet['hash']['sha1'] = self.sha1[i]
+            magnet[URN_PARAMETER_NAME] = {}
+            magnet[URN_PARAMETER_NAME]['sha1'] = self.sha1[i]
             magnet['name'] = strip_dirname(i)
             list_of_magnets.append(magnet)
-        magma['files'] = list_of_magnets
-        return "#MAGMAv0.4\n" + dump(magma, default_flow_style=False)
+        magma[FILE_LIST_NAME] = list_of_magnets
+        return magma
+        
+    def magma(self): 
+        """Dump the yaml version of the file with a MAGMA header."""
+        return MAGMA_0_4_HEADER + "\n" + dump(self.data, default_flow_style=False)
 
 def _test(): 
     from doctest import testmod
