@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env pythons
 # encoding: utf-8
 
 #    magma - Readout and create Magma lists. 
@@ -32,6 +32,11 @@ Examples:
     - magma_list.py magma_from_files example-0.4.magma blah.txt foo.txt gam.txt
 """
 
+__depends__ = "yaml"
+
+from create_simple_magma_list import FILE_LIST_NAME, URN_PARAMETER_NAME, MAGMA_0_4_HEADER
+
+
 # We need yaml loading and dumping as main component. 
 from yaml import load, dump
 
@@ -39,27 +44,20 @@ from yaml import load, dump
 
 class Magma(object):
     """A Magma List."""
-    def __init__(self, magma_file=None, input_files=None, creator=None, data=None):
+    def __init__(self, magma_file=None, input_files=None, creator=None, data=None, yaml_data=None):
         """A Magma list. 
         
         @param magma_file: The path to the magma file, either absolute or relative the the location this script is invoked from. 
         @type magma_file: String
         
         @param input_files: A list of file_paths of input files which should be included in the magma list. 
+        @type input_files: List
         
-        plans: 
-            - Also pass metadata and include that alongside the file list. 
+        @param creator: An identifier for the creator of the Magma file. 
+        @type creator: String
         
-        Ideas: 
-            - If given both magma list and files, the magma list gets extended by the files. 
-            - Joining and seperating magma lists. 
-            - Passing several input lists to join with the main list. 
-            - Passing the data of files along with magma metadata to create the list. 
-            - Passing the indizes of files to automatically slice the list. maybe even with the syntax sliced_magma = magma[a:b]
-            - Readout metadata from files, for example using the taglib or such. 
-            - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done rekursively. 
-            - If hashing files takes very long (for example seen with clock.tick()), give more output. 
-            - Add more commandline switches (verbose, help, ... - see the babtools_gentoo script)
+        @param data: Raw file data as read from a Magma file. 
+        @type data: String
         
         """
         #: All data inside the Magma list
@@ -67,14 +65,17 @@ class Magma(object):
         # if we get data, we assign it. 
         if data is not None: 
             self.data = data
+        # If we get data in yaml format (String), we read it out. 
+        elif yaml_data is not None: 
+            self.data = self.readout_yaml(yaml_data)
         # If we get a magma file, we readout the file itself. 
         elif magma_file is not None: 
-            self.data = self.readout_data(magma_file)
+            self.data = self.readout_magma_from_file(magma_file)
         # If we get single files, we create the magma file from the files. 
         elif input_files is not None: 
             self.data = self.create_magma_from_files(file_paths=input_files)
         else: 
-            raise Exception("No input specified. You need to pass one of data=DATA, magma_file=PATH or input_files=[PATH1, PATH2, ...]")
+            raise Exception("No input specified. Youl need to pass one of data=DATA, magma_file=PATH or input_files=[PATH1, PATH2, ...]")
             
         # If we get a creator name, also add that. 
         if creator is not None: 
@@ -104,7 +105,22 @@ class Magma(object):
         magma = SimpleMagma(file_paths)
         return magma.data
     
-    def readout_data(self, file_path):
+    def readout_yaml(self, yaml_data):
+        """Readout a magma list from data in yaml format.
+        
+        @param yaml_data: Data in yaml format.
+        @type yaml_data: String
+        """
+        # First we now need to check, that this file is in MAGMAv0.4 format. 
+        assert yaml_data[:len(MAGMA_0_4_HEADER)] == MAGMA_0_4_HEADER, "Doesn't begin with Magma v0.4 header " + MAGMA_0_4_HEADER
+        # Now readout the data via yaml and return it. 
+        data = load(yaml_data)
+        # yaml returns None, if nothing is avaible. We need an empty dict though, if the Magma file was empty. 
+        if data is None: 
+            data = {}
+        return data
+    
+    def readout_magma_from_file(self, file_path):
         """Readout a magma list from the file_path
         
         @param file_path: The path to the magma file, either absolute or relative the the location this script is invoked from. 
@@ -115,19 +131,20 @@ class Magma(object):
         file_data = file_handle.read()
         # And close the file. 
         file_handle.close()
-        # Now readout the data via yaml. 
-        data = load(file_data)
         # At the end, return the data. 
-        return data
+        return self.readout_yaml(file_data)
         
     def readout_files(self):
         """Get the files from the magma data"""
         # The files are held as simple list inside the magma file. 
         #: The list of files inside the Magma list. 
         file_list = []
-        # We turn every file dict inside the magma list into a MagmaFile object and return them. 
-        for i in self.data["files"]: 
-            file_list.append(MagmaFile(i))
+        
+        # If the Magma list contains files, we read them. 
+        if FILE_LIST_NAME in self.data.keys(): 
+            # We turn every file dict inside the magma list into a MagmaFile object and return them. 
+            for i in self.data[FILE_LIST_NAME]: 
+                file_list.append(MagmaFile(i))
         # Now the only thing left is returning the list. 
         return file_list
         
@@ -146,7 +163,7 @@ class Magma(object):
         magma_metadata = {}
         # Now we add all subdictionaries, except the "files" subdict. 
         for i in self.data: 
-            if i != "files": 
+            if i != FILE_LIST_NAME: 
                 magma_metadata[i] = self.data[i]
         # That's it. 
         return magma_metadata
@@ -190,7 +207,7 @@ class MagmaFile(object):
         #: The name of the file, so we can easily print it. 
         self.name = self.data["name"]
         #: The sha1 hash of the file. 
-        self.sha1_hash = self.data["hash"]["sha1"]
+        self.sha1_hash = self.data[URN_PARAMETER_NAME]["sha1"]
         #: The magnet link of the file
         self.magnet = self.parse_magnet()
     
